import RepomoduletyperestserverDao from "@/dao/console/repomoduletyperestserver";

export default {
  "config.title": "规则分类",
  "config.toolbar.edit.disabled": ({ component }) => {
    return !component("list").action("getActive");
  },
  "config.toolbar.delete.disabled": ({ component }) => {
    return !component("list").action("getActive");
  },
  "events.init": async ({ dispatch }) => {
    await dispatch("queryRuleGroup");
  },
  "events.toolbarClick/create": async ({ dispatch, modal }) => {
    modal({
      data: {},
      title: "新建",
      schema: [
        {
          prop: "name",
          label: "名称",
          type: "input",
          props: {
            placeholder: "请填写名称",
            showWordLimit: true,
            maxlength: 20
          },
          rules: [
            {
              required: true,
              message: "请填写名称"
            },
            {
              validator: (rule, value, callback) => {
                // 用户查重
                if (value) {
                  const data = {
                    name: value,
                    type: "rule"
                  };
                  RepomoduletyperestserverDao.findByCondition({ data }).then(res => {
                    if (res.data.content.length > 0) {
                      callback(new Error("该名称已被使用"));
                    } else {
                      callback();
                    }
                  });
                }
              },
              trigger: "change"
            }
          ]
        },
        {
          prop: "code",
          label: "编码",
          type: "input",
          props: {
            placeholder: "请填写编码",
            showWordLimit: true,
            maxlength: 20
          }
        }
      ],
      onConfirm: async ({ data, close }) => {
        await dispatch("createRuleGroup", data);
        await dispatch("queryRuleGroup");
        close();
      }
    });
  },
  "events.toolbarClick/edit": async ({ dispatch, component, modal }) => {
    const active = component("list").action("getActive");
    modal({
      data: active,
      title: "编辑",
      schema: [
        {
          prop: "name",
          label: "名称",
          type: "input",
          props: {
            placeholder: "请填写名称",
            showWordLimit: true,
            maxlength: 20
          },
          rules: [
            {
              required: true,
              message: "请填写名称"
            },
            {
              validator: (rule, value, callback) => {
                if (value) {
                  const data = {
                    name: value,
                    type: "rule",
                    id: active.id
                  };
                  RepomoduletyperestserverDao.findByCondition({ data }).then(res => {
                    if (res.data.content.length > 0 && active.id != res.data.content[0].id) {
                      callback(new Error("该名称已被使用"));
                    } else {
                      callback();
                    }
                  });
                }
              },
              trigger: "change"
            }
          ]
        },
        {
          prop: "code",
          label: "编码",
          type: "input",
          props: {
            placeholder: "请填写编码",
            showWordLimit: true,
            maxlength: 20
          }
        }
      ],
      onConfirm: async ({ data, close }) => {
        await dispatch("editRuleGroup", data);
        await dispatch("queryRuletGroup");
        close();
      }
    });
  },
  "events.toolbarClick/delete": async ({ dispatch, component, confirm }) => {
    const active = component("list").action("getActive");
    confirm({
      title: "是否删除",
      content: "即将删除所选数据，是否继续",
      confirmButtonText: "删除",
      cancelButtonText: "关闭",
      onConfirm: async () => {
        await dispatch("deleteRuleGroup", {
          ids: active.id
        });
        await dispatch("queryRuleGroup");
      }
    });
  }
};
