import TemplateGroupDao from "@/dao/template-group";
import TemplateDao from "@/dao/template";
import TemplateVersionDao from "@/dao/template-version";

export default {
  async queryTemplateGroup({ component }) {
    let list = [];
    const resp = await TemplateGroupDao.findByAll();
    const {
      data: { status, content }
    } = resp;
    if (status == "success") {
      list = content;
    }
    component("list1").action("setData", list);
    component("list1").action("setActive");
  },
  async createTemplateGroup({ dispatch }, payload) {
    await TemplateGroupDao.create({
      data: {
        parentId: 0,
        ...payload
      }
    });
    await dispatch("queryTemplateGroup");
  },
  async editTemplateGroup({ dispatch }, payload) {
    await TemplateGroupDao.edit({
      data: payload
    });
    await dispatch("queryTemplateGroup");
  },
  async deleteTemplateGroup({ dispatch }, payload) {
    await TemplateGroupDao.delete({
      params: payload
    });
    await dispatch("queryTemplateGroup");
  },

  async queryTemplate({ component }) {
    const active = component("list1").action("getActive");
    let list = [];
    const resp = await TemplateDao.findByCondition({
      data: { groupId: active.id }
    });
    const {
      data: { status, content }
    } = resp;
    if (status == "success") {
      list = content;
    }
    component("list2").action("setData", list);
    component("list2").action("setActive");
  },
  async createTemplate({ component, dispatch }, payload) {
    const active = component("list1").action("getActive");
    await TemplateDao.create({
      data: { ...payload, groupKey: active.key, groupId: active.id }
    });
    await dispatch("queryTemplate");
  },
  async editTemplate({ dispatch }, payload) {
    await TemplateDao.edit({
      data: payload
    });
    await dispatch("queryTemplate");
  },
  async deleteTemplate({ dispatch }, payload) {
    await TemplateDao.delete({
      params: payload
    });
    await dispatch("queryTemplate");
  },

  async queryTemplateVersion({ component }, payload) {
    const active = component("list2").action("getActive");
    if (!active) {
      return;
    }
    const data = component("table").action("getQueryData");
    data.condition.templateId = active.id;
    component("table").action("setLoading", true);
    try {
      const resp = await TemplateVersionDao.findByPage({
        data
      });
      const { content, status } = resp.data;
      if (status == "success") {
        component("table").action("setData", {
          data: content.rows,
          total: content.total
        });
      }
      component("table").action("setLoading", false);
    } catch (error) {
      component("table").action("setLoading", false);
    }
  },
  async createTemplateVersion({ dispatch }, payload) {
    await TemplateVersionDao.create({
      data: payload
    });
    await dispatch("queryTemplateVersion");
  },
  async editTemplateVersion({ dispatch }, payload) {
    await TemplateVersionDao.edit({
      data: payload
    });
    await dispatch("queryTemplateVersion");
  },
  async deleteTemplateVersion({ dispatch }, payload) {
    await TemplateVersionDao.delete({
      params: payload
    });
    await dispatch("queryTemplateVersion");
  }
};
